summaryrefslogtreecommitdiff
path: root/drivers/staging/tidspbridge/pmgr
diff options
context:
space:
mode:
authorRene Sapiens <rene.sapiens@ti.com>2010-07-10 06:23:57 +0400
committerGreg Kroah-Hartman <gregkh@suse.de>2010-07-22 21:45:34 +0400
commit95870a88ec83be6f10854c9da3bbadf27f3c07c3 (patch)
tree44ff15daf055a8600a31a9516974a61ae38432f9 /drivers/staging/tidspbridge/pmgr
parente68906924d742dfb33564d7eb4ea7db0b4e65ae4 (diff)
downloadlinux-95870a88ec83be6f10854c9da3bbadf27f3c07c3.tar.xz
staging: ti dspbridge: Rename words with camel case.
The intention of this patch is to rename the remaining variables with camel case. Variables will be renamed avoiding camel case and Hungarian notation. The words to be renamed in this patch are: ======================================== hStrm to stream_obj iMode to io_mode irqMask to irq_mask lOffset to offset memPtr to mem_ptr moduleId to module_id msgCallback to msg_callback msgList to msg_list nArgc to num_argc nEntryStart to entry_start nMemSpace to mem_space nStatus to node_status nStrms to strms numLibs to num_libs numLockedEntries to num_locked_entries pageSize to page_sz ======================================== Signed-off-by: Rene Sapiens <rene.sapiens@ti.com> Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
Diffstat (limited to 'drivers/staging/tidspbridge/pmgr')
-rw-r--r--drivers/staging/tidspbridge/pmgr/cod.c16
-rw-r--r--drivers/staging/tidspbridge/pmgr/dbll.c14
-rw-r--r--drivers/staging/tidspbridge/pmgr/dev.c4
-rw-r--r--drivers/staging/tidspbridge/pmgr/msg.c6
4 files changed, 20 insertions, 20 deletions
diff --git a/drivers/staging/tidspbridge/pmgr/dbll.c b/drivers/staging/tidspbridge/pmgr/dbll.c
index 3636aa30733e..1f6719337cb6 100644
--- a/drivers/staging/tidspbridge/pmgr/dbll.c
+++ b/drivers/staging/tidspbridge/pmgr/dbll.c
@@ -156,14 +156,14 @@ static struct dynload_symbol *dbll_find_symbol(struct dynamic_loader_sym *this,
const char *name);
static struct dynload_symbol *dbll_add_to_symbol_table(struct dynamic_loader_sym
*this, const char *name,
- unsigned moduleId);
+ unsigned module_id);
static struct dynload_symbol *find_in_symbol_table(struct dynamic_loader_sym
*this, const char *name,
unsigned moduleid);
static void dbll_purge_symbol_table(struct dynamic_loader_sym *this,
- unsigned moduleId);
+ unsigned module_id);
static void *allocate(struct dynamic_loader_sym *this, unsigned memsize);
-static void deallocate(struct dynamic_loader_sym *this, void *memPtr);
+static void deallocate(struct dynamic_loader_sym *this, void *mem_ptr);
static void dbll_err_report(struct dynamic_loader_sym *this, const char *errstr,
va_list args);
/* dynamic_loader_allocate */
@@ -1094,7 +1094,7 @@ static struct dynload_symbol *find_in_symbol_table(struct dynamic_loader_sym
*/
static struct dynload_symbol *dbll_add_to_symbol_table(struct dynamic_loader_sym
*this, const char *name,
- unsigned moduleId)
+ unsigned module_id)
{
struct dbll_symbol *sym_ptr = NULL;
struct dbll_symbol symbol;
@@ -1150,7 +1150,7 @@ static struct dynload_symbol *dbll_add_to_symbol_table(struct dynamic_loader_sym
* ======== dbll_purge_symbol_table ========
*/
static void dbll_purge_symbol_table(struct dynamic_loader_sym *this,
- unsigned moduleId)
+ unsigned module_id)
{
struct ldr_symbol *ldr_sym = (struct ldr_symbol *)this;
struct dbll_library_obj *lib;
@@ -1183,7 +1183,7 @@ static void *allocate(struct dynamic_loader_sym *this, unsigned memsize)
/*
* ======== deallocate ========
*/
-static void deallocate(struct dynamic_loader_sym *this, void *memPtr)
+static void deallocate(struct dynamic_loader_sym *this, void *mem_ptr)
{
struct ldr_symbol *ldr_sym = (struct ldr_symbol *)this;
struct dbll_library_obj *lib;
@@ -1192,7 +1192,7 @@ static void deallocate(struct dynamic_loader_sym *this, void *memPtr)
lib = ldr_sym->lib;
DBC_REQUIRE(lib);
- kfree(memPtr);
+ kfree(mem_ptr);
}
/*
diff --git a/drivers/staging/tidspbridge/pmgr/dev.c b/drivers/staging/tidspbridge/pmgr/dev.c
index aac448ef5a87..eb4799dd550e 100644
--- a/drivers/staging/tidspbridge/pmgr/dev.c
+++ b/drivers/staging/tidspbridge/pmgr/dev.c
@@ -101,7 +101,7 @@ static void store_interface_fxns(struct bridge_drv_interface *drv_fxns,
* device's bridge_brd_write() function.
*/
u32 dev_brd_write_fxn(void *pArb, u32 ulDspAddr, void *pHostBuf,
- u32 ul_num_bytes, u32 nMemSpace)
+ u32 ul_num_bytes, u32 mem_space)
{
struct dev_object *dev_obj = (struct dev_object *)pArb;
u32 ul_written = 0;
@@ -114,7 +114,7 @@ u32 dev_brd_write_fxn(void *pArb, u32 ulDspAddr, void *pHostBuf,
DBC_ASSERT(dev_obj->hbridge_context != NULL);
status = (*dev_obj->bridge_interface.pfn_brd_write) (
dev_obj->hbridge_context, pHostBuf,
- ulDspAddr, ul_num_bytes, nMemSpace);
+ ulDspAddr, ul_num_bytes, mem_space);
/* Special case of getting the address only */
if (ul_num_bytes == 0)
ul_num_bytes = 1;
diff --git a/drivers/staging/tidspbridge/pmgr/msg.c b/drivers/staging/tidspbridge/pmgr/msg.c
index 64f1cb4bf5ac..6122cd46159d 100644
--- a/drivers/staging/tidspbridge/pmgr/msg.c
+++ b/drivers/staging/tidspbridge/pmgr/msg.c
@@ -46,7 +46,7 @@ static u32 refs; /* module reference count */
* can exist per device object.
*/
int msg_create(OUT struct msg_mgr **phMsgMgr,
- struct dev_object *hdev_obj, msg_onexit msgCallback)
+ struct dev_object *hdev_obj, msg_onexit msg_callback)
{
struct bridge_drv_interface *intf_fxns;
struct msg_mgr_ *msg_mgr_obj;
@@ -55,7 +55,7 @@ int msg_create(OUT struct msg_mgr **phMsgMgr,
DBC_REQUIRE(refs > 0);
DBC_REQUIRE(phMsgMgr != NULL);
- DBC_REQUIRE(msgCallback != NULL);
+ DBC_REQUIRE(msg_callback != NULL);
DBC_REQUIRE(hdev_obj != NULL);
*phMsgMgr = NULL;
@@ -64,7 +64,7 @@ int msg_create(OUT struct msg_mgr **phMsgMgr,
/* Let Bridge message module finish the create: */
status =
- (*intf_fxns->pfn_msg_create) (&hmsg_mgr, hdev_obj, msgCallback);
+ (*intf_fxns->pfn_msg_create) (&hmsg_mgr, hdev_obj, msg_callback);
if (DSP_SUCCEEDED(status)) {
/* Fill in DSP API message module's fields of the msg_mgr
diff --git a/drivers/staging/tidspbridge/pmgr/cod.c b/drivers/staging/tidspbridge/pmgr/cod.c
index a9b049126293..768203535d6e 100644
--- a/drivers/staging/tidspbridge/pmgr/cod.c
+++ b/drivers/staging/tidspbridge/pmgr/cod.c
@@ -155,7 +155,7 @@ static s32 cod_f_read(void __user *pbuffer, s32 size, s32 count,
return -EINVAL;
}
-static s32 cod_f_seek(struct file *filp, s32 lOffset, s32 origin)
+static s32 cod_f_seek(struct file *filp, s32 offset, s32 origin)
{
loff_t dw_cur_pos;
@@ -164,7 +164,7 @@ static s32 cod_f_seek(struct file *filp, s32 lOffset, s32 origin)
return -EFAULT;
/* based on the origin flag, move the internal pointer */
- dw_cur_pos = filp->f_op->llseek(filp, lOffset, origin);
+ dw_cur_pos = filp->f_op->llseek(filp, offset, origin);
if ((s32) dw_cur_pos < 0)
return -EPERM;
@@ -487,12 +487,12 @@ bool cod_init(void)
* loaded must be the first element of the args array and must be a fully
* qualified pathname.
* Details:
- * if nArgc doesn't match the number of arguments in the args array, the
+ * if num_argc doesn't match the number of arguments in the args array, the
* args array is searched for a NULL terminating entry, and argc is
* recalculated to reflect this. In this way, we can support NULL
* terminating args arrays, if nArgc is very large.
*/
-int cod_load_base(struct cod_manager *hmgr, u32 nArgc, char *args[],
+int cod_load_base(struct cod_manager *hmgr, u32 num_argc, char *args[],
cod_writefxn pfn_write, void *pArb, char *envp[])
{
dbll_flags flags;
@@ -503,7 +503,7 @@ int cod_load_base(struct cod_manager *hmgr, u32 nArgc, char *args[],
DBC_REQUIRE(refs > 0);
DBC_REQUIRE(IS_VALID(hmgr));
- DBC_REQUIRE(nArgc > 0);
+ DBC_REQUIRE(num_argc > 0);
DBC_REQUIRE(args != NULL);
DBC_REQUIRE(args[0] != NULL);
DBC_REQUIRE(pfn_write != NULL);
@@ -513,9 +513,9 @@ int cod_load_base(struct cod_manager *hmgr, u32 nArgc, char *args[],
* Make sure every argv[] stated in argc has a value, or change argc to
* reflect true number in NULL terminated argv array.
*/
- for (i = 0; i < nArgc; i++) {
+ for (i = 0; i < num_argc; i++) {
if (args[i] == NULL) {
- nArgc = i;
+ num_argc = i;
break;
}
}
@@ -487,12 +487,12 @@ bool cod_init(void)
* args array is searched for a NULL terminating entry, and argc is
* recalculated to reflect this. In this way, we can support NULL
- * terminating args arrays, if nArgc is very large.
+ * terminating args arrays, if num_argc is very large.
*/